<?php

namespace Drupal\mappi_lane\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Provides a field type of mappi.
 *
 * @FieldType(
 *   id = "mappi",
 *   label = @Translation("Mappi field"),
 *   default_formatter = "mappi_default_formatter",
 *   default_widget = "mappi_default_widget",
 * )
 */

class Mappi extends FieldItemBase {

  public static function defaultFieldSettings()
  {
    return ['customer_base_url' => ''];
  }

  /**
   * {@inheritDoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition)
  {
    return [
      'columns' => [
        'value' => [
          'type' => 'varchar',
          'not null' => TRUE,
          'length' => 255,
        ],
      ],
    ];
  }

  /**
   * {@inheritDoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition)
  {
    $properties['customer_maps'] = DataDefinition::create('string')
      ->setLabel(t('Customer maps'));

    return $properties;
  }

  public function fieldSettingsForm(array $form, FormStateInterface $form_state)
  {

    $element['customer_base_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Base URL customer'),
      '#default_value' => $this->getSetting('customer_base_url'),
      '#placeholder' => ('kaart.katwijk.nl'),
      '#description' => $this->t('Used to call API for all available maps, dont include https and extension'),
    ];

    $element['#element_validate'] = [
      [static::class, 'fieldSettingsFormValidate'],
    ];

    return $element;
  }

  public static function fieldSettingsToConfigData(array $settings)
  {
    return parent::fieldSettingsToConfigData($settings); // TODO: Change the autogenerated stub
  }


  public static function fieldSettingsFormValidate(array $element, FormStateInterface $form_state) {
    $field_name = $form_state->getFormObject()->getEntity()->getName();

    $form_input = $form_state->getValues();
//    $form_state->setValueForElement($element['customer_base_url'])
  }

}
